@@ -20,6 +20,7 @@ structure(function # Compare All Possible Positive-Negative Richards \eqn{nlslis
                           ### optional character value to determine how models are ranked (see Details)
                           taper.ends = 0.45,
                           mod.subset = c(NA),
+                          Envir = .GlobalEnv,
                           ...
                           ) {
 ##description<< This function performs model selection for \code{\link{nlsList}} models fitted using
@@ -33,7 +34,7 @@ structure(function # Compare All Possible Positive-Negative Richards \eqn{nlslis
 ## Fitting these \code{\link{nlsList}} models can be time-consuming (2-4 hours using the dataset
 ## \code{\link{posneg.data}} that encompasses 100 individuals) and if several of the relevant
 ## models are already fitted the option existing=TRUE can be used to avoid refitting models that
-## already exist globally (note that a model object in which no grouping levels were successfully
+## already exist (note that a model object in which no grouping levels were successfully
 ## parameterized will be refitted, as will objects that are not of class nlsList).
 ##
 ## Specifying forcemod=3 will force model selection to only consider fixed M models and setting
@@ -50,16 +51,13 @@ structure(function # Compare All Possible Positive-Negative Richards \eqn{nlslis
 ## standard error is multiplied by). This argument must be a character value
 ## that contains the character n (sample size) and must be a valid right hand side (RHS) of a formula:
 ## e.g. 1*(n), (n)^2. It cannot contain more than one n but could be a custom function, e.g. FUN(n).
-    library(nlme)
+    options(warn = -1)
     alacarte <- FALSE
     "%w/o%" <- function(x, y) x[!x %in% y] #--  x without y
     if(length(mod.subset %w/o% NA) > 0) {
     alacarte <- TRUE 
     }
-    pnoptnm <- as.character(pn.options)
-    testit <- try(library(nlme), silent = TRUE)
-    if (class(testit)[1] == "try-error")
-        stop("please load library: nlme")
+    pnoptnm <- as.character(pn.options[1])
     checkpen <- try(unlist(strsplit(penaliz, "(n)")), silent = TRUE)
     if (length(checkpen) != 2 | class(checkpen)[1] == "try-error") {
         stop("penaliz parameter is ill defined: see ?pn.mod.compare")
@@ -71,51 +69,57 @@ structure(function # Compare All Possible Positive-Negative Richards \eqn{nlslis
     }
     datamerg <- data.frame(x, y, grp)
     userdata <- groupedData(y ~ x | grp, outer = ~grp, data = datamerg)
+    assign("userdata",userdata, envir = Envir)
+    if(as.character(list(Envir)) != "<environment>") stop ("No such environment")
+    if(exists("Envir", mode = "environment") == FALSE) stop ("No such environment")
+    FPCEnv$env <- Envir
     testbounds <- 1
     testpar <- 1
     is.na(testbounds) <- TRUE
     is.na(testpar) <- TRUE
-    testbounds <- try(get(pnoptnm, envir = .GlobalEnv)[16:32],
+    testbounds <- try(get(pnoptnm, envir = Envir)[16:32],
         silent = TRUE)
-    testpar <- try(get(pnoptnm, envir = .GlobalEnv)[1:15],
+    testpar <- try(get(pnoptnm, envir = Envir)[1:15],
         silent = TRUE)
     if (class(testbounds)[1] == "try-error" | class(testpar)[1] ==
         "try-error" | is.na(testbounds[1]) == TRUE | is.na(testpar[1]) ==
         TRUE)
          try({
+         FPCEnv$mod.sel <- TRUE
          modpar(datamerg[,1], datamerg[,2], pn.options = pnoptnm, taper.ends = taper.ends,
-        	verbose=FALSE, ...)
+        	verbose=FALSE, Envir = Envir, ...)
+        options(warn=-1)
+         try(rm("mod.sel", envir = FPCEnv), silent =T)
+         options(warn=0)
          	}, silent = FALSE)    	
-    extraF <- try(get("extraF", envir = .GlobalEnv), silent = TRUE)
+    extraF <- try(get("extraF", pos = 1), silent = TRUE)
     if (class(extraF)[1] == "try-error") {
         stop("cannot find function: extraF - please reload FlexParamCurve")
     }
-    assign(".modcmptemp",get(pnoptnm, envir = .GlobalEnv), .GlobalEnv)
-    .modcmptemp<-".modcmptemp"
     print("checking fit of positive section of the curve for variable M*************************************")
-    richardsR12.lis <- try(get("richardsR12.lis", envir = .GlobalEnv),
+    richardsR12.lis <- try(get(richardsR12.lis, envir = FPCEnv),
         silent = TRUE)
     if (class(richardsR12.lis)[1] == "try-error" | existing ==
         FALSE | (12 %in% mod.subset) == TRUE)
         if(alacarte == FALSE | (12 %in% mod.subset) == TRUE){
-        richardsR12.lis <- try(nlsList(y ~ SSposnegRichards(x,
-            Asym = Asym, K = K, Infl = Infl, M = M, modno = 12, pn.options = .modcmptemp), data = userdata, ...),
-            silent = FALSE)}
+        richardsR12.lis <- eval(parse(text=sprintf("%s",paste("try(nlsList(y ~ SSposnegRichards(x,
+            Asym = Asym, K = K, Infl = Infl, M = M, modno = 12, pn.options = ",pnoptnm, "), data = userdata),
+            silent = TRUE)",sep=""))))}
     print("checking fit of positive section of the curve for fixed M*************************************")
-    pnmodelparams <- get(pnoptnm, envir = .GlobalEnv)[1:15]
-    change.pnparameters <- try(get("change.pnparameters", envir = .GlobalEnv),
+    pnmodelparams <- get(pnoptnm, envir = Envir)[1:15]
+    change.pnparameters <- try(get("change.pnparameters", pos = 1),
         silent = TRUE)
     chk <- try({
     todump<-unlist(summary(richardsR12.lis))["RSE"]
     }, silent = TRUE)
-    richardsR20.lis <- try(get("richardsR20.lis", envir = .GlobalEnv),
+    richardsR20.lis <- try(get(richardsR20.lis, envir = FPCEnv),
         silent = TRUE)
     if (class(richardsR20.lis)[1] == "try-error" | existing ==
         FALSE | (20 %in% mod.subset) == TRUE)
         if(alacarte == FALSE | (20 %in% mod.subset) == TRUE){
-        richardsR20.lis <- try(nlsList(y ~ SSposnegRichards(x,
-            Asym = Asym, K = K, Infl = Infl, modno = 20, pn.options = .modcmptemp), data = userdata, ...),
-            silent = TRUE)}
+        richardsR20.lis <- eval(parse(text=sprintf("%s",paste("try(nlsList(y ~ SSposnegRichards(x,
+            Asym = Asym, K = K, Infl = Infl, modno = 20, pn.options = ",pnoptnm,"), data = userdata),
+            silent = TRUE)",sep=""))))}
     chk1 <- try({
     todump<-unlist(summary(richardsR20.lis))["RSE"]
     }, silent = TRUE)
@@ -125,7 +129,7 @@ structure(function # Compare All Possible Positive-Negative Richards \eqn{nlslis
         forcemod = 4
         richardsR20.lis <- 1
         } else {
-	assign("richardsR20.lis", richardsR20.lis, .GlobalEnv)
+	FPCEnv$richardsR20.lis <- richardsR20.lis
     							}
     if ((class(richardsR12.lis)[1]) == "try-error" | class(chk)[1] == "try-error"
     	| class(richardsR12.lis)[[1]] != "nlsList" )
@@ -134,10 +138,10 @@ structure(function # Compare All Possible Positive-Negative Richards \eqn{nlslis
             forcemod = 3
             richardsR12.lis <- 1
         } else {
-	assign("richardsR12.lis", richardsR12.lis, .GlobalEnv)
+	FPCEnv$richardsR12.lis <- richardsR12.lis
 			}
     currentmodel <- 1
-    testmod <- try(extraF(richardsR20.lis, richardsR12.lis), silent = TRUE)
+    testmod <- try(extraF(richardsR20.lis, richardsR12.lis, warn = F), silent = TRUE)
     if (forcemod == 0) {
         if (class(testmod) == "try-error") {
             modelsig = 0.1
@@ -184,94 +188,98 @@ structure(function # Compare All Possible Positive-Negative Richards \eqn{nlslis
 		if (modelno[1] <20) {
 		    savM <- ",M = M"
         } else {
-            savM <- ","
+            savM <- " "
         }
 		if (modelno[1] < 17 | modelno[1] >= 18) {
 		    savK <- ",K = K"
         } else {
-            savK <- ","
+            savK <- " "
         }
         mod <- 1
-        modnmtry <- paste("richardsR", modelno,".lis", sep = "") 
-        modexist <- try(get(modnmtry, envir = .GlobalEnv), silent = TRUE)
+        options(warn = -1)
+        modnmtry <- paste("FPCEnv$richardsR", modelno,".lis", sep = "") 
+        modexist <- try( eval(parse(modnmtry)), silent = TRUE)
+        options(warn = 0)
         if (class(modexist)[1] == "try-error" | existing == FALSE) {
         if ((modelno %in% mod.subset) == TRUE | alacarte == FALSE) { 
             if (modelno == 1 | modelno == 21)        	 
                 mod <- try(eval(parse(text = sprintf("%s", paste("nlsList(y~SSposnegRichards(x,Asym=Asym",savK,",Infl=Infl",
                   savM, ",RAsym=RAsym,Rk=Rk,Ri=Ri,RM=RM,modno=",
-                  modelno, ", pn.options = .modcmptemp),data=userdata, ...)", sep = "")))),
+                  modelno, ", pn.options = \"",pnoptnm, "\"),data=userdata, ...)", sep = "")))),
                   silent = TRUE)
             if (modelno == 2 | modelno == 22)
                 mod <- try(eval(parse(text = sprintf("%s", paste("nlsList(y~SSposnegRichards(x,Asym=Asym",savK,",Infl=Infl",
                   savM, ",RAsym=RAsym,Rk=Rk,Ri=Ri,modno=",
-                  modelno, ", pn.options = .modcmptemp),data=userdata, ...)", sep = "")))),
+                  modelno, ", pn.options = \"",pnoptnm, "\"),data=userdata, ...)", sep = "")))),
                   silent = TRUE)
             if (modelno == 3 | modelno == 23 | modelno == 17.1)
                 mod <- try(eval(parse(text = sprintf("%s", paste("nlsList(y~SSposnegRichards(x,Asym=Asym",savK,",Infl=Infl",
                   savM, ",Ri=Ri,RM=RM,modno=", modelno,
-                  ", pn.options = .modcmptemp),data=userdata, ...)", sep = "")))), silent = TRUE)
+                  ", pn.options = \"",pnoptnm, "\"),data=userdata, ...)", sep = "")))), silent = TRUE)
             if (modelno == 4 | modelno == 24)
                 mod <- try(eval(parse(text = sprintf("%s", paste("nlsList(y~SSposnegRichards(x,Asym=Asym",savK,",Infl=Infl",
                   savM, ",RAsym=RAsym,RM=RM,modno=",
-                  modelno, ", pn.options = .modcmptemp),data=userdata, ...)", sep = "")))),
+                  modelno, ", pn.options = \"",pnoptnm, "\"),data=userdata, ...)", sep = "")))),
                   silent = TRUE)
             if (modelno == 5 | modelno == 25)
                 mod <- try(eval(parse(text = sprintf("%s", paste("nlsList(y~SSposnegRichards(x,Asym=Asym",savK,",Infl=Infl",
                   savM, ",RM=RM,modno=", modelno,
-                  ", pn.options = .modcmptemp),data=userdata, ...)", sep = "")))), silent = TRUE)
+                  ", pn.options = \"",pnoptnm, "\"),data=userdata, ...)", sep = "")))), silent = TRUE)
             if (modelno == 6 | modelno == 26 | modelno == 17)
                 mod <- try(eval(parse(text = sprintf("%s", paste("nlsList(y~SSposnegRichards(x,Asym=Asym",savK,",Infl=Infl",
                   savM, ",RAsym=RAsym,Ri=Ri,RM=RM,modno=",
-                  modelno, ", pn.options = .modcmptemp),data=userdata, ...)", sep = "")))),
+                  modelno, ", pn.options = \"",pnoptnm, "\"),data=userdata, ...)", sep = "")))),
                   silent = TRUE)
             if (modelno == 7 | modelno == 27)
                 mod <- try(eval(parse(text = sprintf("%s", paste("nlsList(y~SSposnegRichards(x,Asym=Asym",savK,",Infl=Infl",
                   savM, ",Rk=Rk,Ri=Ri,RM=RM,modno=",
-                  modelno, ", pn.options = .modcmptemp),data=userdata, ...)", sep = "")))),
+                  modelno, ", pn.options = \"",pnoptnm, "\"),data=userdata, ...)", sep = "")))),
                   silent = TRUE)
             if (modelno == 8 | modelno == 28)
                 mod <- try(eval(parse(text = sprintf("%s", paste("nlsList(y~SSposnegRichards(x,Asym=Asym",savK,",Infl=Infl",
                   savM, ",RAsym=RAsym,Rk=Rk,RM=RM,modno=",
-                  modelno, ", pn.options = .modcmptemp),data=userdata, ...)", sep = "")))),
+                  modelno, ", pn.options = \"",pnoptnm, "\"),data=userdata, ...)", sep = "")))),
                   silent = TRUE)
             if (modelno == 9 | modelno == 29)
                 mod <- try(eval(parse(text = sprintf("%s", paste("nlsList(y~SSposnegRichards(x,Asym=Asym",savK,",Infl=Infl",
                   savM, ",Rk=Rk,RM=RM,modno=", modelno,
-                  ", pn.options = .modcmptemp),data=userdata, ...)", sep = "")))), silent = TRUE)
+                  ", pn.options = \"",pnoptnm, "\"),data=userdata, ...)", sep = "")))), silent = TRUE)
             if (modelno == 10 | modelno == 30 | modelno == 17.3)
                 mod <- try(eval(parse(text = sprintf("%s", paste("nlsList(y~SSposnegRichards(x,Asym=Asym",savK,",Infl=Infl",
                   savM, ",Ri=Ri,modno=", modelno,
-                  ", pn.options = .modcmptemp),data=userdata, ...)", sep = "")))), silent = TRUE)
+                  ", pn.options = \"",pnoptnm, "\"),data=userdata, ...)", sep = "")))), silent = TRUE)
             if (modelno == 11 | modelno == 31)
                 mod <- try(eval(parse(text = sprintf("%s", paste("nlsList(y~SSposnegRichards(x,Asym=Asym",savK,",Infl=Infl",
                   savM, ",RAsym=RAsym,modno=",
-                  modelno, ", pn.options = .modcmptemp),data=userdata, ...)", sep = "")))),
+                  modelno, ", pn.options = \"",pnoptnm, "\"),data=userdata, ...)", sep = "")))),
                   silent = TRUE)
             if (modelno == 12 | modelno == 32)
                 mod <- try(eval(parse(text = sprintf("%s", paste("nlsList(y~SSposnegRichards(x,Asym=Asym",savK,",Infl=Infl",
                   savM, ",modno=", modelno,
-                  ", pn.options = .modcmptemp),data=userdata, ...)", sep = "")))), silent = TRUE)
+                  ", pn.options = \"",pnoptnm, "\"),data=userdata, ...)", sep = "")))), silent = TRUE)
             if (modelno == 13 | modelno == 33 | modelno == 17.2)
                 mod <- try(eval(parse(text = sprintf("%s", paste("nlsList(y~SSposnegRichards(x,Asym=Asym",savK,",Infl=Infl",
                   savM, ",RAsym=RAsym,Ri=Ri,modno=",
-                  modelno, ", pn.options = .modcmptemp),data=userdata, ...)", sep = "")))),
+                  modelno, ", pn.options = \"",pnoptnm, "\"),data=userdata, ...)", sep = "")))),
                   silent = TRUE)
             if (modelno == 14 | modelno == 34)
                 mod <- try(eval(parse(text = sprintf("%s", paste("nlsList(y~SSposnegRichards(x,Asym=Asym",savK,",Infl=Infl",
                   savM, ",Rk=Rk,Ri=Ri,modno=", modelno,
-                  ", pn.options = .modcmptemp),data=userdata, ...)", sep = "")))), silent = TRUE)
+                  ", pn.options = \"",pnoptnm, "\"),data=userdata, ...)", sep = "")))), silent = TRUE)
             if (modelno == 15 | modelno == 35)
                 mod <- try(eval(parse(text = sprintf("%s", paste("nlsList(y~SSposnegRichards(x,Asym=Asym",savK,",Infl=Infl",
                   savM, ",RAsym=RAsym,Rk=Rk,modno=",
-                  modelno, ", pn.options = .modcmptemp),data=userdata, ...)", sep = "")))),
+                  modelno, ", pn.options = \"",pnoptnm, "\"),data=userdata, ...)", sep = "")))),
                   silent = TRUE)
             if (modelno == 16 | modelno == 36)
                 mod <- try(eval(parse(text = sprintf("%s", paste("nlsList(y~SSposnegRichards(x,Asym=Asym",savK,",Infl=Infl",
                   savM, ",Rk=Rk,modno=", modelno,
-                  ", pn.options = .modcmptemp),data=userdata, ...)", sep = "")))), silent = TRUE)
+                  ", pn.options = \"",pnoptnm, "\"),data=userdata, ...)", sep = "")))), silent = TRUE)
         }
         } else {
-            mod <- try(get(savnm, envir = .GlobalEnv), silent = TRUE)
+            options(warn = -1)
+            mod <- try(eval(parse(paste("FPCEnv$",savnm,sep=""))), silent = TRUE)
+            options(warn = 0)
         }
         if (class(mod)[[1]] != "nlsList")
             mod <- NULL
@@ -285,9 +293,9 @@ structure(function # Compare All Possible Positive-Negative Richards \eqn{nlslis
                 sep = ""))
         } else {
             messagesav <- (paste("**********************  Model ",
-                savnm, " fit successfully and saved in Global Environment   *************************************************",
+                savnm, " fit successfully and saved in FlexParamCurve:::FPCEnv environment   *************************************************",
                 sep = ""))
-            assign(savnm, mod, envir = .GlobalEnv)
+            assign(savnm, mod, envir = as.environment(FPCEnv))
             return(messagesav)
         }
     }
@@ -318,29 +326,34 @@ structure(function # Compare All Possible Positive-Negative Richards \eqn{nlslis
         dfstr <- "df"
         dfstr1 <- "df.residual"
         usefun <- unlist(strsplit(penaliz, "(n)"))
-        model1 <- try(get(modnm, envir = .GlobalEnv), silent = TRUE)
-        checkmod <- try(if (is.null(nrow(coef(model1))) == TRUE) {
-            model1 <- NULL
+        FPCEnv$model1 <- try(get(modnm, envir = as.environment(FPCEnv)), silent = TRUE)
+        if(class(FPCEnv$model1)[1] == "try-error") {
+        FPCEnv$model1 <- NULL
+        checkmod <- NULL
         } else {
-            model1 <- model1
+        checkmod <- try(if (is.null(nrow(coef(FPCEnv$model1))) == TRUE) {
+            FPCEnv$model1 <- NULL
+        } else {
+            FPCEnv$model1 <- FPCEnv$model1
         }, silent = TRUE)
-        evfun <- parse(text = sprintf("%s", paste("summary(model1)[['",
-            RSEstr, "']]*(", usefun[1], "1+sum( summary(model1)[['",
-            dfstr, "']],na.rm=TRUE))", usefun[2], sep = "")))
-        if (class(model1)[[1]] == "nlsList" & class(checkmod)[1] !=
+        }
+        evfun <- parse(text = sprintf("%s", paste("summary(FPCEnv$model1)[['",
+            RSEstr, "']]*(", usefun[1], "(1+sum( summary(FPCEnv$model1)[['",
+            dfstr, "']],na.rm=TRUE)))", usefun[2], sep = "")))
+        if (class(FPCEnv$model1)[1] == "nlsList" & class(checkmod)[1] !=
             "try-error") {
             modrank[i, 2] <- eval(evfun)
-            modrank[i, 3] <- nrow(subset(coef(model1)[1], is.na((coef(model1)[1])) ==
+            modrank[i, 3] <- nrow(subset(coef(FPCEnv$model1)[1], is.na((coef(FPCEnv$model1)[1])) ==
                 FALSE))
             modrank[i, 4] <- eval(parse(text = sprintf("%s",
-                paste("summary(model1)[['", RSEstr, "']]", sep = ""))))
+                paste("summary(FPCEnv$model1)[['", RSEstr, "']]", sep = ""))))
             modrank[i, 5] <- eval(parse(text = sprintf("%s",
-                paste("sum(summary(model1)[['", dfstr, "']][,1],na.rm=TRUE)",
+                paste("sum(summary(FPCEnv$model1)[['", dfstr, "']][,1],na.rm=TRUE)",
                   sep = ""))))
             modrank[i, 6] <- eval(parse(text = sprintf("%s",
-                paste("sum(summary(model1)[['", dfstr1, "']],na.rm=TRUE)",
+                paste("sum(summary(FPCEnv$model1)[['", dfstr1, "']],na.rm=TRUE)",
                   sep = ""))))
-            modrank[i, 7] <- length(coef(model1))
+            modrank[i, 7] <- length(coef(FPCEnv$model1))
         } else {
         }
         modrank[i, 1] <- modnm
@@ -350,16 +363,16 @@ structure(function # Compare All Possible Positive-Negative Richards \eqn{nlslis
     for (i in 1:length(modno)) {
         for (j in 2:(length(modno) - 1)) {
             if (modrank[i, 2] != -999 & modrank[j, 2] != -999) {
-                mod1 <- eval(parse(text = sprintf("%s", modrank[i,
-                  1])))
-                mod2 <- eval(parse(text = sprintf("%s", modrank[j,
-                  1])))
+                mod1 <- eval(parse(text = sprintf("%s", paste("FPCEnv$", modrank[i,
+                  1], sep = ""))))
+                mod2 <- eval(parse(text = sprintf("%s", paste("FPCEnv$", modrank[j,
+                  1], sep = ""))))
                 if (length(coef(mod1)) > length(coef(mod2))) {
                   nmmod1 <- names(coef(mod1))
                   nmmod2 <- names(coef(mod2))
                   if (length(nmmod2 %in% nmmod1) == length(nmmod2))
                     pvalmat[i, j] <- as.numeric(extraF(mod2,
-                      mod1)[4])
+                      mod1, warn = F)[4])
                   if (length(nmmod2 %in% nmmod1) == length(nmmod2))
                     pvalmat[j, i] <- pvalmat[i, j]
                 } else {
@@ -368,7 +381,7 @@ structure(function # Compare All Possible Positive-Negative Richards \eqn{nlslis
                     nmmod2 <- names(coef(mod2))
                     if (length(nmmod1 %in% nmmod2) == length(nmmod1))
                       pvalmat[i, j] <- as.numeric(extraF(mod1,
-                        mod2)[4])
+                        mod2, warn = F)[4])
                     if (length(nmmod1 %in% nmmod2) == length(nmmod1))
                       pvalmat[j, i] <- pvalmat[i, j]
                   } else {
@@ -378,8 +391,8 @@ structure(function # Compare All Possible Positive-Negative Richards \eqn{nlslis
             }
         }
         if (modrank[i, 2] != -999) {
-        modtemp <- eval(parse(text = sprintf("%s", modrank[i,
-            1])))
+        modtemp <- eval(parse(text = sprintf("%s", paste("FPCEnv$", modrank[i,
+            1], sep =""))))
         modnm <- paste("R", as.character(modno[i]), ".lis", sprintf("(%s)",
             length(coef(modtemp))), sep = "")
         row.names(pvalmat)[i] <- paste("R", as.character(modno[i]),
@@ -402,8 +415,18 @@ structure(function # Compare All Possible Positive-Negative Richards \eqn{nlslis
     modrank[(modrank[,6])==Inf,6] <- NA
     row.names(modrank) <- c(1:length(modno))
     print("...done")
+    print("writing output to environment:")
+    print(Envir)
+    get.mod(to.envir = Envir, write.mod = TRUE)
+    assign("userdata",userdata, envir = Envir)
     outp <- list(modrank, pvalmat)
     names(outp) <- c("Model rank table", "P values from pairwise extraF comparisons")
+    options(warn=-1)
+    try(rm("model1",envir = FPCEnv),silent=T)
+    try(rm("tempparam.select",envir = FPCEnv),silent=T)
+    try(rm("tempmodnm",envir = FPCEnv),silent=T)
+    try(rm("legitmodel",envir = FPCEnv),silent=T)
+    options(warn = 0)
     return(outp)
     ##value<<  A list object with two components: $'Model rank table' contains the
     ## statistics from \code{\link{extraF}} ranked by the  modified residual standard error,
@@ -424,7 +447,6 @@ structure(function # Compare All Possible Positive-Negative Richards \eqn{nlslis
 }
 , ex = function(){
 #run model selection for posneg.data object (only first 3 group levels for example's sake)
-data(posneg.data)
 subdata <- subset(posneg.data, as.numeric(row.names (posneg.data) ) < 40)
 modseltable <- pn.mod.compare(subdata$age, subdata$mass,
     subdata$id, existing = FALSE)
